#
# spec file for package belr
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname  libbelr
%define sover   1
Name:           belr
Version:        5.3.95
Release:        1.2
Summary:        Language recognition library
License:        GPL-3.0-or-later
Group:          Development/Tools/Other
URL:            https://linphone.org/
Source:         https://gitlab.linphone.org/BC/public/belr/-/archive/%{version}/%{name}-%{version}.tar.bz2
Source1:        baselibs.conf
# PATCH-FIX-OPENSUSE belr-fix-pkgconfig.patch sor.alexei@meowr.ru -- Install belr.pc.
Patch0:         belr-fix-pkgconfig.patch
Patch1:         set_current_version.patch
BuildRequires:  cmake >= 3.22
BuildRequires:  gcc-c++
BuildRequires:  libudev-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(bctoolbox) >= %{version}

%description
Belr parses input formatted according to a language defined by an
ABNF grammar, such as the protocols standardised at IETF.

%package -n %{soname}%{sover}
Summary:        Language recognition library
Group:          Development/Tools/Other

%description -n %{soname}%{sover}
Belr parses input formatted according to a language defined by an
ABNF grammar, such as the protocols standardised at IETF.

%package devel
Summary:        Headers and libraries for the belr library
Group:          Development/Tools/Other
Requires:       %{soname}%{sover} = %{version}

%description devel
Belr parses input formatted according to a language defined by an
ABNF grammar, such as the protocols standardised at IETF.

This package contains header files and development libraries needed
to develop applications using the belr library.

%prep
%autosetup -p1

%build
%cmake \
  -DENABLE_STRICT=OFF \
  -DENABLE_STATIC=OFF
%cmake_build

%install
%cmake_install

%post -n %{soname}%{sover} -p /sbin/ldconfig
%postun -n %{soname}%{sover} -p /sbin/ldconfig

%files -n %{soname}%{sover}
%license LICENSE.txt
%{_libdir}/%{soname}.so.%{sover}*

%files devel
%license LICENSE.txt
%doc CHANGELOG.md README.md
%dir %{_libdir}/cmake
%dir %{_libdir}/cmake/Belr/
%{_bindir}/%{name}*
%{_includedir}/%{name}/
%{_libdir}/%{soname}.so
%{_libdir}/cmake/Belr/
%{_datadir}/%{name}/
%{_datadir}/%{name}-tester/
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Mon Nov 11 2024 ecsos <ecsos@opensuse.org>
- Update to 5.3.95 (no changelog).
* Fri Mar 29 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.3.37 (no changelog).
* Thu Mar  7 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.3.26 (no changelog)
* Mon Jan 15 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.3.7 (no changelog)
* Mon Aug 28 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.2.98 (no changelog)
- Add set_current_version.patch.
* Sun Apr 16 2023 Dirk Müller <dmueller@suse.com>
- update to 5.2.51:
  * Fix bug resulting in empty matches not being considered as
    valid when enclosed within a selector.
  * Fix build using flexisip flags
* Wed Jan 11 2023 Giacomo Comes <gcomes.obs@gmail.com> - 5.2.9
- Update to version 5.2.9:
  * Fix syntax error in Github issue template
  * Added Github yml issue template
  * Parse integers as long long
* Wed Dec  7 2022 Dirk Müller <dmueller@suse.com>
- update to 5.1.72:
  * version bump, no source code change
* Wed Jun  8 2022 Giacomo Comes <gcomes.obs@gmail.com> - 5.1.32
- Update to version 5.1.32:
  * Fix syntax error in Github issue template
  * Parse integers as long long
* Wed Apr 27 2022 Giacomo Comes <gcomes.obs@gmail.com>
- Update to version 5.1.12:
  * no changes
* Tue Mar 15 2022 Dirk Müller <dmueller@suse.com>
- revert license tag change:
  * no GPL-3.0-only declaration could be found in source
* Tue Feb  1 2022 Giacomo Comes <gcomes.obs@gmail.com> - 5.0.67
- Update to version 5.0.67:
  * no changes
- fix license tag
* Sun Nov 21 2021 Giacomo Comes <gcomes.obs@gmail.com> - 5.0.53
- Update to version 5.0.53:
  * no changes
* Mon Nov  8 2021 Giacomo Comes <gcomes.obs@gmail.com> - 5.0.49
- Update to version 5.0.49:
  * No changes
* Tue Nov  2 2021 Giacomo Comes <gcomes.obs@gmail.com> - 5.0.46
- Update to version 5.0.46:
  * No changes
* Tue Oct 19 2021 Giacomo Comes <gcomes.obs@gmail.com> - 5.0.36
- Update to version 5.0.36:
  * Cast on assert to remove warning on x64
  * Remove a useless usage shared_ptr<> in the Parser and Regognizers
* Sat Jul  3 2021 Giacomo Comes <gcomes.obs@gmail.com> - 4.5.20
- Update to version 4.5.20:
  * No changes
- fix several RPMLINT warning
* Thu Apr 15 2021 Luiz Angelo Daros de Luca <luizluca@tre-sc.jus.br>
- Update to 4.5.3:
  * No changelog available.
* Wed Jul 29 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 4.4.0:
  * Fix a bug with the use of createRootObject().
    It wasn't passed the size of what was really parsed, which was
    confusing for the DebugParser and the output of belr-parse tool.
  * Add Iphlpapi dependency for using liblinphone
    GetAdaptersAddresses.
* Wed Apr 22 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 4.3.1 (changes since 0.1.3):
  * belr-compiler tool, to generate binary grammar files, that can
    be loaded hundred times faster than txt grammars.
  * Optimise size of user application object code, due to template
    instanciation of belr classes.
  * Install cmake config files into the correct path.
  * Use BcTooblox macros for source archive generation.
  * CMakeLists.txt: Introduce the ENABLE_PACKAGE_SOURCE option.
  * Licence moves to GNU GPLv3+.
  * Add better documentation in README.
* Mon Nov 18 2019 Simon Lees <sflees@suse.de>
- %%make_jobs is depricated replaced by %%cmake_build
- Use %%autopatch
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Tue Mar  5 2019 Martin Pluskal <mpluskal@suse.com>
- Modernise spec file with spec-cleaner
* Fri Jul 21 2017 sor.alexei@meowr.ru
- Update to version 0.1.3:
  * Bug fixes.
- Remove belr-0.1.2-fix-includedir.patch: fixed upstream.
* Sun Jul  2 2017 sor.alexei@meowr.ru
- Add belr-0.1.2-fix-includedir.patch: Fix includedir
  (from commit a515fda).
* Sun May 28 2017 jengelh@inai.de
- Rectify RPM group, trim filler wording from description.
* Wed May 17 2017 sor.alexei@meowr.ru
- Initial package.
